@@ -2,7 +2,7 @@
  * Caja-Actions
  * A Caja extension which offers configurable context menu actions.
  *
- * Copyright (C) 2005 The MATE Foundation
+ * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
  * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
@@ -214,9 +214,6 @@ cact_icommand_tab_init( CactICommandTab *instance )
 static void
 on_base_initialize_gtk( CactICommandTab *instance, GtkWindow *toplevel, gpointer user_data )
 {
-#if GTK_CHECK_VERSION( 3,0,0 )
-	base_gtk_utils_table_to_grid( BASE_WINDOW( instance ), "table220" );
-#endif
 }
 
 /*
@@ -669,7 +666,7 @@ update_example_label( CactICommandTab *instance, NAObjectProfile *profile )
 		/* convert special xml chars (&, <, >,...) to avoid warnings
 		 * generated by Pango parser
 		 */
-		/* i18n: command-line example: Ex.: /bin/ls file1.txt file2.txt */
+		/* Translators: command-line example: Ex.: /bin/ls file1.txt file2.txt */
 		newlabel = g_markup_printf_escaped(
 				"<i><b><span size=\"small\">%s</span></b></i>", parameters );
 
