@@ -2,7 +2,7 @@
  * Caja-Actions
  * A Caja extension which offers configurable context menu actions.
  *
- * Copyright (C) 2005 The MATE Foundation
+ * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
  * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
@@ -31,8 +31,8 @@
 #include <config.h>
 #endif
 
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <libintl.h>
 #include <stdlib.h>
 #include <string.h>
 
